Miscellaneous utility functions
named_list(lst = NULL, name_fields = "name")is_url(x, https_only = FALSE)
is_empty(x)
get_paged_list(lst, token, next_link_name = "nextLink", value_name = "value")
A named list of objects.
The components of the objects in lst, to be used as names.
For is_url and is_empty, An R object.
For is_url, whether to allow only HTTPS URLs.
For get_paged_list, an Azure OAuth token, of class AzureToken.
For get_paged_list, the names of the next link and value components in the lst argument. The default values are correct for Resource Manager.
For named_list, the list that was passed in but with names. An empty input results in a named list output: a list of length 0, with a names attribute.
For get_paged_list, a list.
For is_url, whether the object appears to be a URL (is character of length 1, and starts with the string "http"). Optionally, restricts the check to HTTPS URLs only. For is_empty, whether the length of the object is zero (this includes the special case of NULL).
named_list extracts from each object in lst, the components named by name_fields. It then constructs names for lst from these components, separated by a "/".
get_paged_list reconstructs a complete list of objects from a paged response. Many Resource Manager list operations will return paged output, that is, the response contains a subset of all items, along with a URL to query to retrieve the next subset. get_paged_list retrieves each subset and returns all items in a single list.